Changelog
=========

1.11.0
------
#. Django 1.11 compatibility.

1.9.2
-----
#. Ensure widget HTML is marked as safe.
#. Use a rendering engine that has access to standard template tags.

1.9.1
-----
#. Add missing migrations.

1.9.0
-----
#. Django 1.9 compatibility.

0.1.2
-----
#. Correctly include MANIFEST.in

0.1.1
-----
#. List app as part of sites app.

0.1
---
#. Initial release.

